@@ -30,31 +30,31 @@
 /* ======================================================================== */
 #define DEFAULT_CHART_HEIGHT 30
 
-SoundMonitor		*sound;
+SoundMonitor	*gkrellmss;
 
-static Monitor		*mon_sound;
-Chart				*chart;
-static ChartConfig	*chart_config;
+static GkrellmMonitor *mon_sound;
+static GkrellmChartconfig *chart_config;
 
 static gint			style_id;
 
+#if !defined(GKRELLM_HAVE_THEME_SCALE)
 static GdkPixmap	*button_sweep_up_pixmap,
 					*button_sweep_dn_pixmap;
 static GdkBitmap	*button_sweep_up_mask,
 					*button_sweep_dn_mask;
+#endif
 
-static Decal		*decal_sweep_up,
+static GkrellmDecal	*decal_sweep_up,
 					*decal_sweep_dn;
 
-static Decal		*decal_mode_button;
+static GkrellmDecal	*decal_mode_button;
 
-Decal				*decal_label0,	/* Chart labels */
-					*decal_label1;
 
-static Krell		*krell_in_motion;
+static GkrellmKrell	*krell_in_motion;
 
 static gint			vu_meter_width;
 
+
 static void
 draw_mode_button(gboolean pressed)
 	{
@@ -63,60 +63,62 @@ draw_mode_button(gboolean pressed)
 	x = gkrellm_chart_width() - decal_mode_button->w + 1;
 	frame = pressed ? D_MISC_BUTTON_IN : D_MISC_BUTTON_OUT;
 	gkrellm_draw_decal_pixmap(NULL, decal_mode_button, frame);
-	gkrellm_draw_decal_on_chart(chart, decal_mode_button, x, 0);
+	gkrellm_draw_decal_on_chart(gkrellmss->chart, decal_mode_button, x, 0);
 	}
 
-void
+static void
 draw_sound_chart(gboolean force_reset, gboolean draw_grid)
 	{
-	if (sound->mode == SOUND_MODE_OSCOPE)
-		draw_oscope(force_reset, draw_grid);
-	else if (sound->mode == SOUND_MODE_SPECTRUM)
-		draw_spectrum(force_reset, draw_grid);
-	if (sound->mouse_in_chart)
-		draw_mode_button(sound->mode_button_pressed);
-	gkrellm_draw_chart_to_screen(chart);
-	sound->streaming = FALSE;
+	if (gkrellmss->mode == SOUND_MODE_OSCOPE)
+		gkrellmss_draw_oscope(force_reset, draw_grid);
+	else if (gkrellmss->mode == SOUND_MODE_SPECTRUM)
+		gkrellmss_draw_spectrum(force_reset, draw_grid);
+	if (gkrellmss->mouse_in_chart)
+		draw_mode_button(gkrellmss->mode_button_pressed);
+	gkrellm_draw_chart_to_screen(gkrellmss->chart);
+	gkrellmss->streaming = FALSE;
 	}
 
 static gint
 cb_chart_release(GtkWidget *widget, GdkEventButton *ev, gpointer data)
 	{
-	sound->mode_button_pressed = FALSE;
+	gkrellmss->mode_button_pressed = FALSE;
 	return TRUE;
 	}
 
 static gint
 cb_chart_press(GtkWidget *widget, GdkEventButton *ev, gpointer data)
 	{
+	Spectrum	*spectrum = gkrellmss->spectrum;
+
 	if (gkrellm_in_decal(decal_mode_button, ev))
 		{
-		sound->mode += 1;
-		if (sound->mode >= N_SOUND_MODES)
-			sound->mode = 0;
-		sound->mode_button_pressed = TRUE;
+		gkrellmss->mode += 1;
+		if (gkrellmss->mode >= N_SOUND_MODES)
+			gkrellmss->mode = 0;
+		gkrellmss->mode_button_pressed = TRUE;
 		gkrellm_config_modified();
 		draw_sound_chart(FORCE_RESET, DRAW_GRID);
 		}
-	else if (ev->button == 1 && ev->type == GDK_BUTTON_PRESS)
+	else if (gkrellmss->stream_open && ev->button == 1)
 		{
-		if (sound->mode == SOUND_MODE_SPECTRUM && !spectrum->reset)
+		if (gkrellmss->mode == SOUND_MODE_SPECTRUM && !spectrum->reset)
 			{
 			if (spectrum->x_highlight > 0)
 				spectrum->x_highlight = 0;
 			else
-				spectrum->x_highlight = sound->x_mouse;
+				spectrum->x_highlight = gkrellmss->x_mouse;
 			}
 		}
-	else if (ev->button == 2)
+	else if (ev->button == 2 || !gkrellmss->stream_open)
 		{
-		if (sound->fd < 0)
+		if (!gkrellmss->stream_open)
 			{
-			sound_open_stream(sound->host);
+			gkrellmss_sound_open_stream(gkrellmss->host);
 			}
 		else
 			{
-			sound->extra_info = !sound->extra_info;
+			gkrellmss->extra_info = !gkrellmss->extra_info;
 			gkrellm_config_modified();
 			draw_sound_chart(FORCE_RESET, 0);
 			}
@@ -124,24 +126,25 @@ cb_chart_press(GtkWidget *widget, GdkEventButton *ev, gpointer data)
 	else if (   ev->button == 3
 			 || (ev->button == 1 && ev->type == GDK_2BUTTON_PRESS)
 			)
-		gkrellm_chartconfig_window_create(chart);
+		gkrellm_chartconfig_window_create(gkrellmss->chart);
 	return TRUE;
 	}
 
 static void
 update_sound(void)
 	{
+	Oscope		*oscope = gkrellmss->oscope;
 	gint		d, left, right, left_peak, right_peak;
 
-	if ((left = sound->left_value) > oscope->vert_max)
+	if ((left = gkrellmss->left_value) > oscope->vert_max)
 		left = oscope->vert_max;
-	if ((right = sound->right_value) > oscope->vert_max)
+	if ((right = gkrellmss->right_value) > oscope->vert_max)
 		right = oscope->vert_max;
-	left_peak = sound->left_peak_value - oscope->vert_max / 30;
-	if ((d = sound->left_peak_value - left) > 0)
+	left_peak = gkrellmss->left_peak_value - oscope->vert_max / 30;
+	if ((d = gkrellmss->left_peak_value - left) > 0)
 		left_peak -= d / 30;
-	right_peak = sound->right_peak_value - oscope->vert_max / 30;
-	if ((d = sound->right_peak_value - right) > 0)
+	right_peak = gkrellmss->right_peak_value - oscope->vert_max / 30;
+	if ((d = gkrellmss->right_peak_value - right) > 0)
 		right_peak -= d / 30;
 
 	if (left_peak < left)
@@ -149,77 +152,83 @@ update_sound(void)
 	if (right_peak < right)
 		right_peak = right;
 
-	gkrellm_update_krell(chart->panel, sound->krell_left, left);
-	gkrellm_update_krell(chart->panel, sound->krell_left_peak, left_peak);
-	gkrellm_update_krell(chart->panel, sound->krell_right, right);
-	gkrellm_update_krell(chart->panel, sound->krell_right_peak, right_peak);
+	gkrellm_update_krell(gkrellmss->chart->panel, gkrellmss->krell_left, left);
+	gkrellm_update_krell(gkrellmss->chart->panel, gkrellmss->krell_left_peak, left_peak);
+	gkrellm_update_krell(gkrellmss->chart->panel, gkrellmss->krell_right, right);
+	gkrellm_update_krell(gkrellmss->chart->panel, gkrellmss->krell_right_peak, right_peak);
 
-	sound->left_peak_value = left_peak;
-	sound->right_peak_value = right_peak;
-	sound->left_value = 0;
-	sound->right_value = 0;
+	gkrellmss->left_peak_value = left_peak;
+	gkrellmss->right_peak_value = right_peak;
+	gkrellmss->left_value = 0;
+	gkrellmss->right_value = 0;
 
-	d = sound->krell_sensitivity_y_target - sound->krell_sensitivity_y;
+	d = gkrellmss->krell_sensitivity_y_target - gkrellmss->krell_sensitivity_y;
 	if (d > 0)
 		{
-		sound->krell_sensitivity_y += 1 + d / 4;
-		gkrellm_move_krell_yoff(chart->panel, sound->krell_sensitivity,
-					sound->krell_sensitivity_y);
+		gkrellmss->krell_sensitivity_y += 1 + d / 4;
+		gkrellm_move_krell_yoff(gkrellmss->chart->panel, gkrellmss->krell_sensitivity,
+					gkrellmss->krell_sensitivity_y);
 		}
 	else if (d < 0)
 		{
-		sound->krell_sensitivity_y -= 1 - d / 4;
-		gkrellm_move_krell_yoff(chart->panel, sound->krell_sensitivity,
-					sound->krell_sensitivity_y);
+		gkrellmss->krell_sensitivity_y -= 1 - d / 4;
+		gkrellm_move_krell_yoff(gkrellmss->chart->panel, gkrellmss->krell_sensitivity,
+					gkrellmss->krell_sensitivity_y);
 		}
 
-	gkrellm_draw_panel_layers(chart->panel);
+	gkrellm_draw_panel_layers(gkrellmss->chart->panel);
 
 	draw_sound_chart(0, 0);
-	sound->streaming = FALSE;
+	gkrellmss->streaming = FALSE;
 	}
 
 
 static void
 sound_vertical_scaling(void)
 	{
-	gfloat	audio_taper;
+	Oscope		*oscope = gkrellmss->oscope;
+	Spectrum	*spectrum = gkrellmss->spectrum;
+	gfloat		audio_taper;
+	gint		spectrum_factor;
 
-	audio_taper = log(1 + sound->vert_sensitivity) / log(2.0);
+	audio_taper = log(1 + gkrellmss->vert_sensitivity) / log(2.0);
 
 	oscope->vert_max = (gint) (audio_taper * 32767.0);
-	spectrum->vert_max = (gint) (audio_taper * 24);
-	gkrellm_set_krell_full_scale(sound->krell_left, oscope->vert_max, 1);
-	gkrellm_set_krell_full_scale(sound->krell_right, oscope->vert_max, 1);
-	gkrellm_set_krell_full_scale(sound->krell_left_peak, oscope->vert_max, 1);
-	gkrellm_set_krell_full_scale(sound->krell_right_peak, oscope->vert_max, 1);
+
+	spectrum_factor = spectrum->scale_index > 0 ? 24 : 16;
+	spectrum->vert_max = (gint) (audio_taper * spectrum_factor);
+
+	gkrellm_set_krell_full_scale(gkrellmss->krell_left, oscope->vert_max, 1);
+	gkrellm_set_krell_full_scale(gkrellmss->krell_right, oscope->vert_max, 1);
+	gkrellm_set_krell_full_scale(gkrellmss->krell_left_peak, oscope->vert_max, 1);
+	gkrellm_set_krell_full_scale(gkrellmss->krell_right_peak, oscope->vert_max, 1);
 	}
 
 static void
-update_slider_position(Krell *k, gint x_ev)
+update_slider_position(GkrellmKrell *k, gint x_ev)
 	{
 	gint	x,
 			w = gkrellm_chart_width();
 
-	if (x_ev < sound->vu_x0)
-		x_ev = sound->vu_x0;
+	if (x_ev < gkrellmss->vu_x0)
+		x_ev = gkrellmss->vu_x0;
 	if (x_ev >= w)
 		x_ev = w - 1;
-	sound->x_sensitivity_raw = x_ev;
-	x = x_ev - sound->vu_x0;
+	gkrellmss->x_sensitivity_raw = x_ev;
+	x = x_ev - gkrellmss->vu_x0;
 	x = k->full_scale * x / (vu_meter_width - 1);
 	if (x < 0)
 		x = 0;
 
-	sound->vert_sensitivity = (100.0 - (gfloat) x) / 100.0;
-	if (sound->vert_sensitivity < 0.05)
-		sound->vert_sensitivity = 0.05;
-	if (sound->vert_sensitivity > 1.0)
-		sound->vert_sensitivity = 1.0;
+	gkrellmss->vert_sensitivity = (100.0 - (gfloat) x) / 100.0;
+	if (gkrellmss->vert_sensitivity < 0.05)
+		gkrellmss->vert_sensitivity = 0.05;
+	if (gkrellmss->vert_sensitivity > 1.0)
+		gkrellmss->vert_sensitivity = 1.0;
 	sound_vertical_scaling();
 	gkrellm_config_modified();
-	gkrellm_update_krell(chart->panel, k, (gulong) x);
-	gkrellm_draw_panel_layers(chart->panel);
+	gkrellm_update_krell(gkrellmss->chart->panel, k, (gulong) x);
+	gkrellm_draw_panel_layers(gkrellmss->chart->panel);
 	}
 
 
@@ -228,10 +237,10 @@ expose_event(GtkWidget *widget, GdkEventExpose *ev)
 	{
 	GdkPixmap	*pixmap	= NULL;
 
-	if (widget == chart->panel->drawing_area)
-		pixmap = chart->panel->pixmap;
-	else if (widget == chart->drawing_area)
-		pixmap = chart->pixmap;
+	if (widget == gkrellmss->chart->panel->drawing_area)
+		pixmap = gkrellmss->chart->panel->pixmap;
+	else if (widget == gkrellmss->chart->drawing_area)
+		pixmap = gkrellmss->chart->pixmap;
 	if (pixmap)
 		gdk_draw_pixmap(widget->window, gkrellm_draw_GC(1), pixmap,
 				ev->area.x, ev->area.y, ev->area.x, ev->area.y,
@@ -243,17 +252,17 @@ expose_event(GtkWidget *widget, GdkEventExpose *ev)
 static gboolean
 cb_chart_enter(GtkWidget *w, GdkEventButton *ev, gpointer data)
 	{
-	sound->mouse_in_chart = TRUE;
+	gkrellmss->mouse_in_chart = TRUE;
 	draw_mode_button(FALSE);
-	gkrellm_draw_chart_to_screen(chart);
+	gkrellm_draw_chart_to_screen(gkrellmss->chart);
 	return TRUE;
 	}
 
 static gint
 cb_chart_leave(GtkWidget *w, GdkEventButton *ev, gpointer data)
 	{
-	sound->mouse_in_chart = FALSE;
-	sound->mode_button_pressed = FALSE;
+	gkrellmss->mouse_in_chart = FALSE;
+	gkrellmss->mode_button_pressed = FALSE;
 	draw_sound_chart(FORCE_RESET, 0);
 	return TRUE;
 	}
@@ -261,26 +270,34 @@ cb_chart_leave(GtkWidget *w, GdkEventButton *ev, gpointer data)
 static gint
 cb_chart_motion(GtkWidget *widget, GdkEventButton *ev)
 	{
-	sound->x_mouse = ev->x;
+	gkrellmss->x_mouse = ev->x;
 	return TRUE;
 	}
 
 static gint
 cb_panel_enter(GtkWidget *widget, GdkEventButton *ev)
 	{
-	sound->krell_sensitivity_y_target = sound->krell_sensitivity_y_dn;
+	gkrellmss->krell_sensitivity_y_target = gkrellmss->krell_sensitivity_y_dn;
 	return TRUE;
 	}
 
 static gint
 cb_panel_leave(GtkWidget *widget, GdkEventButton *ev)
 	{
-	sound->krell_sensitivity_y_target = sound->krell_sensitivity_y_up;
+	gkrellmss->krell_sensitivity_y_target = gkrellmss->krell_sensitivity_y_up;
 	return TRUE;
 	}
 
 static gint
 cb_panel_release(GtkWidget *widget, GdkEventButton *ev)
+	{
+	if (ev->button == 1)
+		krell_in_motion = NULL;
+	return TRUE;
+	}
+
+static gint
+cb_panel_scroll(GtkWidget *widget, GdkEventScroll *ev)
 	{
 	gint	dx = 0;
 	gint	delta;
@@ -288,29 +305,26 @@ cb_panel_release(GtkWidget *widget, GdkEventButton *ev)
 	delta = vu_meter_width / 30;
 	if (delta == 0)
 		delta = 1;
-	if (ev->button == 1)
-		krell_in_motion = NULL;
-	else if (ev->button == 4)
+	if (ev->direction == GDK_SCROLL_UP)
 		dx = delta;
-	else if (ev->button == 5)
+	else if (ev->direction == GDK_SCROLL_DOWN)
 		dx = -delta;
-	if (dx)
-		update_slider_position(sound->krell_sensitivity,
-					sound->x_sensitivity_raw + dx);
+	update_slider_position(gkrellmss->krell_sensitivity,
+				gkrellmss->x_sensitivity_raw + dx);
 	return TRUE;
 	}
 
 static gint
 cb_panel_press(GtkWidget *widget, GdkEventButton *ev)
     {
-	Krell	*k = sound->krell_sensitivity;
+	GkrellmKrell	*k = gkrellmss->krell_sensitivity;
 
 	if (ev->button == 3)
 		{
 		gkrellm_open_config_window(mon_sound);
 		return TRUE;
 		}
-	if (   ev->button == 1 && ev->x > sound->vu_x0
+	if (   ev->button == 1 && ev->x > gkrellmss->vu_x0
 		&& ev->y >= k->y0 && ev->y <= k->y0 + k->h_frame)
 		{
 		krell_in_motion = k;
@@ -323,7 +337,7 @@ static gint
 cb_panel_motion(GtkWidget *widget, GdkEventButton *ev)
 	{
 	GdkModifierType	state;
-	Krell			*k;
+	GkrellmKrell	*k;
 
 	if (krell_in_motion)
 		{
@@ -345,9 +359,9 @@ cb_panel_motion(GtkWidget *widget, GdkEventButton *ev)
 static void
 height_changed(gpointer data)
 	{
-	if (sound->mode == SOUND_MODE_SPECTRUM)
+	if (gkrellmss->mode == SOUND_MODE_SPECTRUM)
 		{
-		load_spectrum_images();
+		gkrellmss_load_spectrum_images();
 		}
 	draw_sound_chart(FORCE_RESET, DRAW_GRID);
 	}
@@ -355,18 +369,18 @@ height_changed(gpointer data)
 static void
 create_chart(GtkWidget *vbox, gint first_create)
 	{
-	Chart		*cp = chart;
+	GkrellmChart	*cp = gkrellmss->chart;
 
 	/* Create some decals that will be drawn on the chart.  They won't live
 	|  in a panel where they can be automatically destroyed, so I must
     |  destroy them at create events and then recreate them with NULL panel
 	|  and style pointers.
 	*/
-	gkrellm_destroy_decal(decal_label0);
-	gkrellm_destroy_decal(decal_label1);
-	decal_label0 = gkrellm_create_decal_text(NULL, "888 msec",
+	gkrellm_destroy_decal(gkrellmss->label0_decal);
+	gkrellm_destroy_decal(gkrellmss->label1_decal);
+	gkrellmss->label0_decal = gkrellm_create_decal_text(NULL, "888 msec",
 			gkrellm_chart_alt_textstyle(DEFAULT_STYLE_ID), NULL, 2, 0, 0);
-	decal_label1 = gkrellm_create_decal_text(NULL, "8.8K",
+	gkrellmss->label1_decal = gkrellm_create_decal_text(NULL, "8.8K",
 			gkrellm_chart_alt_textstyle(DEFAULT_STYLE_ID), NULL, 2, 0, 0);
 
 	gkrellm_destroy_decal(decal_mode_button);
@@ -401,35 +415,36 @@ create_chart(GtkWidget *vbox, gint first_create)
 				"motion_notify_event", (GtkSignalFunc) cb_chart_motion, NULL);
 		gtk_widget_show(vbox);
 		}
-	oscope_horizontal_scaling();
-	load_spectrum_images();
+	gkrellmss_oscope_horizontal_scaling();
+	gkrellmss_load_spectrum_images();
 	draw_sound_chart(FORCE_RESET, DRAW_GRID);
 	}
 
 static void
-cb_sweep_pressed(DecalButton *button)
+cb_sweep_pressed(GkrellmDecalbutton *button)
 	{
-	gint	dir;
+	Oscope		*oscope = gkrellmss->oscope;
+	gint		dir;
 
 	dir = GPOINTER_TO_INT(button->data);
 	dir = (dir == 0) ? 1 : -1;
-	if (sound->mode == SOUND_MODE_OSCOPE)
+	if (gkrellmss->mode == SOUND_MODE_OSCOPE)
 		{
 		oscope->usec_per_div = gkrellm_125_sequence(oscope->usec_per_div + dir,
 				TRUE, LOW_SWEEP, HIGH_SWEEP, FALSE, FALSE);
-		oscope_horizontal_scaling();
+		gkrellmss_oscope_horizontal_scaling();
 		}
-	else if (sound->mode == SOUND_MODE_SPECTRUM)
-		change_spectrum_scale(dir);
+	else if (gkrellmss->mode == SOUND_MODE_SPECTRUM)
+		gkrellmss_change_spectrum_scale(dir);
 	draw_sound_chart(FORCE_RESET, 0);
 	}
 
 static void
-create_panel_buttons(Panel *p)
+create_panel_buttons(GkrellmPanel *p)
 	{
-	GdkImlibImage	*im	= NULL;
-	Style			*style;
-	Margin			*margin;
+	GkrellmPiximage	*im	= NULL;
+	GkrellmStyle	*style;
+	GkrellmMargin	*margin;
 	gint			x, y;
 
 	style = gkrellm_meter_style(style_id);
@@ -438,47 +453,64 @@ create_panel_buttons(Panel *p)
 	y = 3;
 	gkrellm_get_gkrellmrc_integer("sound_button_sweep_yoff", &y);
 
-	if (!gkrellm_load_image("buttom_sweep_dn", NULL, &im, STYLE_NAME))
-		gkrellm_load_image("button_sweep_dn", button_sweep_dn_xpm,
+	if (!gkrellm_load_piximage("buttom_sweep_dn", NULL, &im, STYLE_NAME))
+		gkrellm_load_piximage("button_sweep_dn", button_sweep_dn_xpm,
 					&im, STYLE_NAME);
-	gkrellm_render_to_pixmap(im, &button_sweep_dn_pixmap,
+
+#if defined(GKRELLM_HAVE_THEME_SCALE)
+	y *= gkrellm_get_theme_scale();
+	decal_sweep_dn = gkrellm_make_scaled_decal_pixmap(p, im, style,
+				2, margin->left, y, 0, 0);
+#else
+	gkrellm_scale_piximage_to_pixmap(im, &button_sweep_dn_pixmap,
 				&button_sweep_dn_mask, 0, 0);
 	decal_sweep_dn = gkrellm_create_decal_pixmap(p, button_sweep_dn_pixmap,
 				button_sweep_dn_mask, 2, style, margin->left, y);
+#endif
+	gkrellm_make_decal_button(p, decal_sweep_dn, cb_sweep_pressed,
+				GINT_TO_POINTER(0), 1, 0);
 
 	x = decal_sweep_dn->x;
 	y = decal_sweep_dn->y;
 
-	if (!gkrellm_load_image("buttom_sweep_up", NULL, &im, STYLE_NAME))
-		gkrellm_load_image("button_sweep_up", button_sweep_up_xpm,
+	if (!gkrellm_load_piximage("buttom_sweep_up", NULL, &im, STYLE_NAME))
+		gkrellm_load_piximage("button_sweep_up", button_sweep_up_xpm,
 					&im, STYLE_NAME);
-	gkrellm_render_to_pixmap(im, &button_sweep_up_pixmap,
+#if defined(GKRELLM_HAVE_THEME_SCALE)
+	decal_sweep_up = gkrellm_make_scaled_decal_pixmap(p, im, style,
+				2, x + decal_sweep_dn->w, y, 0, 0);
+#else
+	gkrellm_scale_piximage_to_pixmap(im, &button_sweep_up_pixmap,
 				&button_sweep_up_mask, 0, 0);
 	decal_sweep_up = gkrellm_create_decal_pixmap(p, button_sweep_up_pixmap,
 				button_sweep_up_mask, 2, style,
 				x + decal_sweep_dn->w, y);
-
+#endif
+	gkrellm_make_decal_button(p, decal_sweep_up, cb_sweep_pressed,
+				GINT_TO_POINTER(1), 1, 0);
 
 	gkrellm_decal_on_top_layer(decal_sweep_dn, TRUE);
 	gkrellm_decal_on_top_layer(decal_sweep_up, TRUE);
 
-	sound->vu_x0 = decal_sweep_up->x + decal_sweep_up->w;
-	vu_meter_width = gkrellm_chart_width() - sound->vu_x0;
+	gkrellmss->vu_x0 = decal_sweep_up->x + decal_sweep_up->w;
+	vu_meter_width = gkrellm_chart_width() - gkrellmss->vu_x0;
 	}
 
-static Krell *
-default_or_themed_krell(Panel *p, gchar *name, GdkImlibImage *im, gint yoff,
-	gint depth, gint x_hot, gint expand, gint left_margin, gint right_margin)
+static GkrellmKrell *
+default_or_themed_krell(GkrellmPanel *p, gchar *name, GkrellmPiximage *im,
+		gint yoff, gint depth, gint x_hot, gint expand,
+		gint left_margin, gint right_margin)
 	{
-	Krell	*k;
-	Style	*style;
+	GkrellmKrell	*k;
+	GkrellmStyle	*style;
+	gint			y;
 
 	/* Work with a copy since we may modify the style.
 	*/
 	style = gkrellm_copy_style(gkrellm_meter_style_by_name(name));
-	if (!gkrellm_style_is_themed(style))
+	if (!gkrellm_style_is_themed(style, 0))
 		gkrellm_set_style_krell_values(style, yoff, depth, x_hot,
-				expand, left_margin, right_margin);
+				expand, 1, left_margin, right_margin);
 	else
 		{
 		if (style->krell_left_margin == 0)
@@ -487,6 +519,12 @@ default_or_themed_krell(Panel *p, gchar *name, GdkImlibImage *im, gint yoff,
 	k = gkrellm_create_krell(p, im, style);
 	gkrellm_monotonic_krell_values(k, FALSE);
 
+	y = k->y0;
+#if defined(GKRELLM_HAVE_THEME_SCALE)
+	y *= gkrellm_get_theme_scale();
+#endif
+	gkrellm_move_krell_yoff(p, k, y);
+
 	/* Unlike the style pointer passed to gkrellm_panel_configure(), the krells
 	|  don't need the style to persist.
 	*/
@@ -497,101 +535,123 @@ default_or_themed_krell(Panel *p, gchar *name, GdkImlibImage *im, gint yoff,
 static void
 create_panel(GtkWidget *vbox, gint first_create)
 	{
-	GdkImlibImage	*im = NULL;
-	Panel			*p;
+	GkrellmPiximage	*im = NULL;
+	GkrellmPanel	*p;
 	gint			x;
 
-	p = chart->panel;
+	p = gkrellmss->chart->panel;
 	create_panel_buttons(p);
-	x = sound->vu_x0;
+	x = gkrellmss->vu_x0;
 
-	gkrellm_load_image("krell_vu", krell_vu_xpm, &im, STYLE_NAME);
-	sound->krell_left = default_or_themed_krell(p, "sound.vu_left",
+	gkrellm_load_piximage("krell_vu", krell_vu_xpm, &im, STYLE_NAME);
+	gkrellmss->krell_left = default_or_themed_krell(p, "sound.vu_left",
 				im, 3, 1, 59, KRELL_EXPAND_LEFT, x, 0);
-	sound->krell_right = default_or_themed_krell(p, "sound.vu_right",
+	gkrellmss->krell_right = default_or_themed_krell(p, "sound.vu_right",
 				im, 9, 1, 59, KRELL_EXPAND_LEFT, x, 0);
 
-	gkrellm_load_image("krell_vu_peak", krell_vu_peak_xpm, &im, STYLE_NAME);
-	sound->krell_left_peak = default_or_themed_krell(p, "sound.vu_left_peak",
+	gkrellm_load_piximage("krell_vu_peak", krell_vu_peak_xpm, &im, STYLE_NAME);
+	gkrellmss->krell_left_peak = default_or_themed_krell(p, "sound.vu_left_peak",
 				im, 2, 5, -1, KRELL_EXPAND_NONE, x, 0);
-	sound->krell_right_peak = default_or_themed_krell(p, "sound.vu_right_peak",
+	gkrellmss->krell_right_peak = default_or_themed_krell(p, "sound.vu_right_peak",
 				im, 8, 5, -1, KRELL_EXPAND_NONE, x, 0);
 
 	sound_vertical_scaling();
 
-	gkrellm_load_image("krell_sensitivity", krell_sensitivity_xpm,
+	gkrellm_load_piximage("krell_sensitivity", krell_sensitivity_xpm,
 				&im, STYLE_NAME);
-	sound->krell_sensitivity = default_or_themed_krell(p, "sound.sensitivity",
+	gkrellmss->krell_sensitivity = default_or_themed_krell(p, "sound.sensitivity",
 				im, 0, 1, -1, KRELL_EXPAND_NONE, x, 0);
-	gkrellm_set_krell_full_scale(sound->krell_sensitivity, 100, 1);
+	gkrellm_set_krell_full_scale(gkrellmss->krell_sensitivity, 100, 1);
 
-	sound->krell_sensitivity_y_up = -10;
-	sound->krell_sensitivity_y_dn = 0;
+	gkrellmss->krell_sensitivity_y_up = -10;
+	gkrellmss->krell_sensitivity_y_dn = 0;
 	gkrellm_get_gkrellmrc_integer("sound_krell_sensitivity_y_up",
-			&sound->krell_sensitivity_y_up);
+			&gkrellmss->krell_sensitivity_y_up);
 	gkrellm_get_gkrellmrc_integer("sound_krell_sensitivity_y_dn",
-			&sound->krell_sensitivity_y_dn);
-	sound->krell_sensitivity_y_target = sound->krell_sensitivity_y_up;
+			&gkrellmss->krell_sensitivity_y_dn);
 
-	if (im)
-		gdk_imlib_kill_image(im);
+#if defined(GKRELLM_HAVE_THEME_SCALE)
+	gkrellmss->krell_sensitivity_y_up *= gkrellm_get_theme_scale();
+	gkrellmss->krell_sensitivity_y_dn *= gkrellm_get_theme_scale();
+#endif
+	gkrellmss->krell_sensitivity_y_target = gkrellmss->krell_sensitivity_y_up;
+
+	gkrellm_destroy_piximage(im);
 
 	gkrellm_panel_configure(p, NULL, gkrellm_meter_style(style_id));
 	gkrellm_panel_create(vbox, mon_sound, p);
 
-	gkrellm_make_decal_button(p, decal_sweep_dn, cb_sweep_pressed,
-				GINT_TO_POINTER(0), 1, 0);
-	gkrellm_make_decal_button(p, decal_sweep_up, cb_sweep_pressed,
-				GINT_TO_POINTER(1), 1, 0);
-
 	if (first_create)
 		{
-		gtk_signal_connect(GTK_OBJECT (p->drawing_area),
-				"expose_event", (GtkSignalFunc) expose_event, NULL);
-		gtk_signal_connect(GTK_OBJECT(p->drawing_area),
-				"button_press_event", (GtkSignalFunc) cb_panel_press, NULL);
-		gtk_signal_connect(GTK_OBJECT(p->drawing_area),
-				"button_release_event", (GtkSignalFunc) cb_panel_release,NULL);
-		gtk_signal_connect(GTK_OBJECT (p->drawing_area),
-				"motion_notify_event", (GtkSignalFunc) cb_panel_motion, NULL);
-		gtk_signal_connect(GTK_OBJECT(p->drawing_area),
-				"enter_notify_event", (GtkSignalFunc) cb_panel_enter, NULL);
-		gtk_signal_connect(GTK_OBJECT(p->drawing_area),
-				"leave_notify_event", (GtkSignalFunc) cb_panel_leave, NULL);
+		g_signal_connect(G_OBJECT(p->drawing_area),
+				"expose_event", G_CALLBACK(expose_event), NULL);
+		g_signal_connect(G_OBJECT(p->drawing_area),
+				"button_press_event", G_CALLBACK(cb_panel_press), NULL);
+		g_signal_connect(G_OBJECT(p->drawing_area),
+				"button_release_event", G_CALLBACK(cb_panel_release), NULL);
+		g_signal_connect(G_OBJECT(p->drawing_area),
+				"scroll_event", G_CALLBACK(cb_panel_scroll), NULL);
+		g_signal_connect(G_OBJECT(p->drawing_area),
+				"motion_notify_event", G_CALLBACK(cb_panel_motion), NULL);
+		g_signal_connect(G_OBJECT(p->drawing_area),
+				"enter_notify_event", G_CALLBACK(cb_panel_enter), NULL);
+		g_signal_connect(G_OBJECT(p->drawing_area),
+				"leave_notify_event", G_CALLBACK(cb_panel_leave), NULL);
 		}
-	gkrellm_update_krell(chart->panel, sound->krell_sensitivity,
-				(gulong) (100.0 * (1.0 - sound->vert_sensitivity)));
-	sound->x_sensitivity_raw = (gint) ((1.0 - sound->vert_sensitivity)
-				* (gfloat) vu_meter_width) + sound->vu_x0;
+	gkrellm_update_krell(gkrellmss->chart->panel, gkrellmss->krell_sensitivity,
+				(gulong) (100.0 * (1.0 - gkrellmss->vert_sensitivity)));
+	gkrellmss->x_sensitivity_raw = (gint) ((1.0 - gkrellmss->vert_sensitivity)
+				* (gfloat) vu_meter_width) + gkrellmss->vu_x0;
 
 	/* To get the negative y_up, must move the krell since the create
 	|  interprets negative offsets as special placement codes.
 	*/
-	gkrellm_move_krell_yoff(p, sound->krell_sensitivity,
-				sound->krell_sensitivity_y_up);
+	gkrellm_move_krell_yoff(p, gkrellmss->krell_sensitivity,
+				gkrellmss->krell_sensitivity_y_up);
+	}
+
+static void
+gkrellmss_alloc_data(void)
+	{
+	if (!gkrellmss->buffer)
+		{
+		gkrellmss->buf_len = N_SAMPLES;
+		gkrellmss->buffer = g_new0(SoundSample, gkrellmss->buf_len);
+		}
+	gkrellmss_spectrum_alloc_data();
 	}
 
 static void
 create_sound(GtkWidget *vbox, gint first_create)
 	{
+	gkrellmss_alloc_data();
 	if (first_create)
 		{
-		chart = gkrellm_chart_new0();
-		chart->panel = gkrellm_panel_new0();
-		sound_open_stream(sound->host);
+		gkrellmss->chart = gkrellm_chart_new0();
+		gkrellmss->chart->panel = gkrellm_panel_new0();
+		gkrellmss_sound_open_stream(gkrellmss->host);
 		}
-	sound->gc = gkrellm_draw_GC(1);
+	gkrellmss->gc = gkrellm_draw_GC(1);
 	create_chart(vbox, first_create);
 	create_panel(vbox, first_create);
+#if defined(GKRELLM_CHECK_VERSION)
+#if GKRELLM_CHECK_VERSION(2,1,0)
+	gkrellm_spacers_set_types(mon_sound,
+				GKRELLM_SPACER_CHART, GKRELLM_SPACER_METER);
+#endif
+#endif
 	}
 
 
 static void
 save_config(FILE *f)
 	{
-	fprintf(f, "%s mode %d\n", CONFIG_KEYWORD, sound->mode);
-	fprintf(f, "%s sensitivity %f\n", CONFIG_KEYWORD, sound->vert_sensitivity);
-	fprintf(f, "%s extra_info %d\n", CONFIG_KEYWORD, sound->extra_info);
+	Oscope		*oscope = gkrellmss->oscope;
+	Spectrum	*spectrum = gkrellmss->spectrum;
+
+	fprintf(f, "%s mode %d\n", CONFIG_KEYWORD, gkrellmss->mode);
+	fprintf(f, "%s sensitivity %f\n", CONFIG_KEYWORD, gkrellmss->vert_sensitivity);
+	fprintf(f, "%s extra_info %d\n", CONFIG_KEYWORD, gkrellmss->extra_info);
 	fprintf(f, "%s usec_per_div %d\n", CONFIG_KEYWORD, oscope->usec_per_div);
 	fprintf(f, "%s spectrum_scale %d\n", CONFIG_KEYWORD,spectrum->scale_index);
 	gkrellm_save_chartconfig(f, chart_config, CONFIG_KEYWORD, NULL);
@@ -600,24 +660,26 @@ save_config(FILE *f)
 static void
 load_config(gchar *arg)
 	{
-	gchar	config[32], item[CFG_BUFSIZE];
-	gint	n;
+	Oscope		*oscope = gkrellmss->oscope;
+	Spectrum	*spectrum = gkrellmss->spectrum;
+	gchar		config[32], item[CFG_BUFSIZE];
+	gint		n;
 
 	n = sscanf(arg, "%31s %[^\n]", config, item);
 	if (n != 2)
 		return;
 	if (!strcmp(config, "mode"))
-		sscanf(item, "%d", &sound->mode);
+		sscanf(item, "%d", &gkrellmss->mode);
 	else if (!strcmp(config, "sensitivity"))
 		{
-		sscanf(item, "%f", &sound->vert_sensitivity);
-		if (sound->vert_sensitivity < 0.05)
-			sound->vert_sensitivity = 0.05;
-		if (sound->vert_sensitivity > 1.0)
-			sound->vert_sensitivity = 1.0;
+		sscanf(item, "%f", &gkrellmss->vert_sensitivity);
+		if (gkrellmss->vert_sensitivity < 0.05)
+			gkrellmss->vert_sensitivity = 0.05;
+		if (gkrellmss->vert_sensitivity > 1.0)
+			gkrellmss->vert_sensitivity = 1.0;
 		}
 	else if (!strcmp(config, "extra_info"))
-		sscanf(item, "%d", &sound->extra_info);
+		sscanf(item, "%d", &gkrellmss->extra_info);
 	else if (!strcmp(config, "usec_per_div"))
 		sscanf(item, "%d", &oscope->usec_per_div);
 	else if (!strcmp(config, "spectrum_scale"))
@@ -627,28 +689,23 @@ load_config(gchar *arg)
 	}
 
 /* --------------------------------------------------------------------- */
-static void
-apply_config(void)
-	{
-	}
-
 
 static gchar	*info_text[] =
 {
-N_("<b>GKrellMSS - GKrellM Sound Scope\n"),
+N_("<h>GKrellMSS - GKrellM Sound Scope\n"),
 "\n",
-N_("<b>VU Meter\n"),
+N_("<h>VU Meter\n"),
 N_("Two fast response krells show left and right audio signal levels\n"
 	"averaged over about 1/20 sec.  There are also two slow decay peak\n"
 	"response krells.\n"),
 "\n",
 
-N_("<b>Chart\n"),
+N_("<h>Chart\n"),
 N_("The chart has oscilloscope and spectrum analyzer modes toggled by\n"
 	"pressing the mode button on the chart.\n"),
 "\n",
 
-N_("<b>Panel Buttons\n"),
+N_("<h>Panel Buttons\n"),
 N_("In oscilloscope mode, the two buttons to the left of the VU Meter select\n"
 	"an oscope horizontal sweep speed ranging from 100 microseconds (usec)\n"
 	"per division to 50 miliseconds (msec) per division.  There are 5\n"
@@ -659,7 +716,7 @@ N_("In spectrum analyzer mode, the two buttons select a frequency resolution\n"
 	"and range.  As the '>' button is pressed, there is better lower\n"
 	"frequency resolution at the expense of slower update times.\n"),
 "\n",
-N_("<b>\nMouse Button Actions:\n"),
+N_("<h>\nMouse Button Actions:\n"),
 N_("<b>\tLeft "),
 N_("click and drag in the VU Meter krell region to adjust VU Meter.\n"
 	"\t\tand chart sensitivity.\n"),
@@ -691,28 +748,29 @@ create_tab(GtkWidget *tab_vbox)
 
 #if 0
 /* --Options Tab */
-	vbox = gkrellm_create_framed_tab(tabs, _("Options"));
+	vbox = gkrellm_gtk_framed_notebook_page(tabs, _("Options"));
 #endif
 
 
 /* --Info tab */
-	vbox = gkrellm_create_framed_tab(tabs, _("Info"));
-	text = gkrellm_scrolled_text(vbox, NULL,
+	vbox = gkrellm_gtk_framed_notebook_page(tabs, _("Info"));
+	text = gkrellm_gtk_scrolled_text_view(vbox, NULL,
 				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	for (i = 0; i < sizeof(info_text)/sizeof(gchar *); ++i)
-		gkrellm_add_info_text_string(text, _(info_text[i]));
+		gkrellm_gtk_text_view_append(text, _(info_text[i]));
 
 /* --About tab */
-	vbox = gkrellm_create_framed_tab(tabs, _("About"));
+	vbox = gkrellm_gtk_framed_notebook_page(tabs, _("About"));
 	label = gtk_label_new("");
 	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
 
-	buf = g_strdup_printf(_("GKrellMSS %d.%d\nGKrellM Sound Scope\n\n"
+	buf = g_strdup_printf(_("GKrellMSS %d.%d %s\nGKrellM Sound Scope\n\n"
 				"Copyright (c) 2002 by Bill Wilson\n"
 				"bill@gkrellm.net\n"
 				"http://gkrellm.net\n\n"
 				"Released under the GNU Public License"),
-				GKRELLMSS_VERSION_MAJOR, GKRELLMSS_VERSION_MINOR);
+				GKRELLMSS_VERSION_MAJOR, GKRELLMSS_VERSION_MINOR,
+				GKRELLMSS_EXTRAVERSION);
 	label = gtk_label_new(buf);
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 	g_free(buf);
@@ -722,14 +780,14 @@ create_tab(GtkWidget *tab_vbox)
 	}
 
 
-static Monitor	monitor_sound =
+static GkrellmMonitor	monitor_sound =
 	{
 	N_(CONFIG_NAME),	/* Name, for config tab.	*/
 	0,					/* Id,  0 if a plugin		*/
 	create_sound,		/* The create function		*/
 	update_sound,		/* The update function		*/
 	create_tab,			/* The config tab create function	*/
-	apply_config,		/* Apply the config function		*/
+	NULL,				/* Everthing is instant apply */
 
 	save_config,		/* Save user conifg			*/
 	load_config,		/* Load user config			*/
@@ -745,25 +803,35 @@ static Monitor	monitor_sound =
 	NULL				/* path if a plugin, filled in by GKrellM		*/
 	};
 
-Monitor *
-init_plugin(void)
+GkrellmMonitor *
+gkrellm_init_plugin(void)
 	{
+	gchar	*dummy_utf8 = NULL;
+
+#ifdef ENABLE_NLS
+	bind_textdomain_codeset("gkrellm-gkrellmss", "UTF-8");
+#endif
+
 	monitor_sound.name = _(monitor_sound.name);
 	mon_sound = &monitor_sound;
 
-	sound = g_new0(SoundMonitor, 1);
-	sound->x_sensitivity_raw = gkrellm_chart_width() / 2;
-	sound->extra_info = TRUE;
-	sound->vert_sensitivity = 0.5;
+	gkrellmss = g_new0(SoundMonitor, 1);
+	gkrellmss->x_sensitivity_raw = gkrellm_chart_width() / 2;
+	gkrellmss->extra_info = TRUE;
+	gkrellmss->vert_sensitivity = 0.5;
+
+	gkrellmss->oscope = gkrellmss_init_oscope();
+
+	gkrellmss->spectrum = gkrellmss_init_spectrum();
 
 	style_id = gkrellm_add_meter_style(mon_sound, STYLE_NAME);
 
-	init_oscope();
-	init_spectrum();
+	gkrellm_locale_dup_string(&dummy_utf8,
+			_("\\cNo sound server?\\n\\f\\cClick here to\\n\\f\\ctry to open"),
+			&gkrellmss->server_error);
+	g_free(dummy_utf8);
+
 
 	return &monitor_sound;
 	}
 
-/* check sensitivity yoff
-   left_margin == 0 => use vu_y0
-*/
